@@ -170,7 +170,7 @@ def force_add_random_vertex(C):
 	if np.any(~colored_vertices):
 		vertices_per_color = np.sum(C,axis=1)
 		proposal_weights = np.max(vertices_per_color) - vertices_per_color + 0.2
-		skewed_proposal_weights = (proposal_weights / np.max(proposal_weights))**2
+		skewed_proposal_weights = (proposal_weights / np.max(proposal_weights))**3
 		weights = skewed_proposal_weights / np.sum(skewed_proposal_weights)
 
 		uncolored_vertex = np.random.choice( np.nonzero(~colored_vertices)[0] )
@@ -256,6 +256,49 @@ def parallel_add_random_vertex(C):
 
 	return check_average_and_add_row(C)
 
+
+"""
+
+Works well but slow
+
+List Complrehensions:
+
+[ np.sum(gcp.edges_matrix[c][:,uncolored_vertex]) for c in C]
+[np.all( ~gcp.edges_matrix[c][:,60] ) for c in T]
+
+probably faster....
+
+"""
+
+def massive_try_single_vertex(C):
+	C = C.copy()
+	colored_vertices = np.any( C,axis=0 )
+
+	if np.any(~colored_vertices):
+		uncolored_vertices = np.nonzero(~colored_vertices)[0]
+		uncolored_vertex = np.random.choice(uncolored_vertices)
+
+		conflict_in_colors = np.array([ np.sum(edges_matrix[c][:,uncolored_vertex]) for c in C])
+
+		if np.any(conflict_in_colors == 0):
+			color_without_conflict = np.nonzero(conflict_in_colors == 0 )[0][0]
+			C[color_without_conflict, uncolored_vertex] = True
+
+			return check_average_and_add_row(C)
+
+		if np.any(conflict_in_colors == 1):
+			single_conflicts = conflict_in_colors == 1
+
+			random_single_conflict_color = np.random.choice( np.nonzero(single_conflicts)[0] )
+
+
+			C[random_single_conflict_color] = ~edges_matrix[ uncolored_vertex ] & C[random_single_conflict_color]
+			C[random_single_conflict_color][uncolored_vertex] = True
+			
+			return check_average_and_add_row(C)
+	
+	return C
+
 def check_free_vertex_recoloring(C):
 	C = C.copy()
 	np.random.shuffle(C)
